@@ -47,7 +47,11 @@ class ProcessLinewiseInteractiveHandler(DexyHandler):
                 section_transcript += proc.before
                 start = proc.after
             output_dict[k] = section_transcript
-        proc.close()
+        try:
+            proc.close()
+        except pexpect.ExceptionPexpect:
+            print "process %s may not have closed" % proc.pid
+
         if proc.exitstatus is not None and proc.exitstatus != 0:
             if not (self.IGNORE_ERRORS or self.doc.controller.args.ignore_errors):
                 raise Exception("""proc returned nonzero status code! if you don't
@@ -67,7 +71,7 @@ class ProcessSectionwiseInteractiveHandler(DexyHandler):
     TRAILING_PROMPT = "\r\n> "
     INPUT_EXTENSIONS = ['.txt', '.r', '.R']
     OUTPUT_EXTENSIONS = ['.Rout']
-    ALIASES = ['rint']
+    ALIASES = ['r', 'rint']
 
     def process_dict(self, input_dict):
         output_dict = OrderedDict()
@@ -99,7 +103,7 @@ class ProcessSectionwiseInteractiveHandler(DexyHandler):
             proc.expect(self.COMMENT * 5, timeout = timeout)
 
             section_transcript += proc.before.rstrip(self.TRAILING_PROMPT)
-            output_dict[k] = section_transcript
+            output_dict[k] = ''.join([c for c in section_transcript if ord(c) > 31 or ord(c) in [9, 10]])
 
         return output_dict
 
@@ -133,40 +137,6 @@ class ProcessTimingHandler(DexyHandler):
             times.append("%s" % (time.time() - start))
         self.artifact.data_dict['1'] = "\n".join(times)
 
-class ROutputHandler(DexyHandler):
-    """Runs R code in batch mode. Returns a full transcript, including commands and output from each line."""
-    EXECUTABLE = 'R CMD BATCH --vanilla --quiet --no-timing'
-    VERSION = "R --version"
-    INPUT_EXTENSIONS = ['.txt', '.r', '.R']
-    OUTPUT_EXTENSIONS = [".Rout"]
-    ALIASES = ['r']
-
-    def process(self):
-        self.artifact.generate_workfile()
-        wf = self.artifact.work_filename()
-        af = self.artifact.filename()
-        pexpect.run("%s %s %s" % (self.EXECUTABLE, wf, af), cwd=self.artifact.artifacts_dir)
-        self.artifact.data_dict['1'] = open(self.artifact.filepath(), "r").read()
-
-
-class RArtifactHandler(DexyHandler):
-    """Runs R code in batch mode. Uses the --slave flag so doesn't echo commands, just returns output."""
-    EXECUTABLE = 'R CMD BATCH --vanilla --quiet --slave --no-timing'
-    VERSION = "R --version"
-    INPUT_EXTENSIONS = ['.txt', '.r', '.R']
-    OUTPUT_EXTENSIONS = [".txt"]
-    ALIASES = ['rart']
-
-    def process(self):
-        self.artifact.generate_workfile()
-
-        work_file = os.path.basename(self.artifact.work_filename())
-        artifact_file = os.path.basename(self.artifact.filename())
-        command = "%s %s %s" % (self.EXECUTABLE, work_file, artifact_file)
-        self.log.info(command)
-        self.artifact.stdout = pexpect.run(command, cwd=self.artifact.artifacts_dir)
-        self.artifact.data_dict['1'] = open(self.artifact.filename(), "r").read()
-
 class Pdf2Jpg(DexyHandler):
     """
     Converts a PDF file to JPEG format.
